/***************************************************************************
    dialogmediainfo.cpp
                             -------------------
                             
    begin                : March 2015
    copyright            : (c) 2015 by Iven Wold - 526f6c616e642053756368616e
    email                : hour.glass2@yahoo.com
    license              : GPL v 2.0
    
   DialogAnimation class
    
****************************************************************************/

#include <qmessagebox.h>
#include <qlineedit.h>
//#include <qcombobox.h>
//#include <qspinbox.h>
//#include <qslider.h>
#include <QMessageBox>		//xxx

#include "sourcefileentry.h"
#include "dialogmovie.h"
#include "dialogmediainfo.h"

//DialogMediaInfo::DialogMediaInfo (QWidget *pParent, const char *pName, Qt::WFlags f )		//ooo
DialogMediaInfo::DialogMediaInfo (QWidget *pParent)						//xxx
	//: uiDialogMediaInfo (pParent, pName, f)	//ooo
	: QDialog (pParent)				//xxx
{
  setupUi(this);	//xxx
}

DialogMediaInfo::~DialogMediaInfo ()
{
}

void DialogMediaInfo::initMe  ( SourceFileInfo *pSourceFileInfo )
{
  m_pEditVideoAspect->setText ( pSourceFileInfo->qsRatio       );
  m_pEditVideoFPS->setText    ( pSourceFileInfo->qsFPS         );
  m_pEditVideoLength->setText ( pSourceFileInfo->qsLength      );
  m_pEditVideoFormat->setText ( pSourceFileInfo->qsVideoFormat );
  m_pEditAudioBits->setText   ( pSourceFileInfo->qsBits        );
  m_pEditAudioBPS->setText    ( pSourceFileInfo->qsBPS         );
  m_pEditAudioSample->setText ( pSourceFileInfo->qsSample      );
}

